==> krename_3.0.3.orig.tar.gz: krename-3.0.3/krename/wizard.h <==
/***************************************************************************
                          wizard.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WIZARD_H
#define WIZARD_H

// KDE includes
#include <kwizard.h>
class QCloseEvent;
class KRenameImpl;
class KMenuBar;
class QCloseEvent;
class QHBoxLayout;
class QRect;
class QString;
class QVBoxLayout;
class QWidget;
class wizard : public KWizard
{ 
    Q_OBJECT

    public:
        wizard( KRenameImpl* impl, QRect r, QWidget* parent = 0, const char* name = 0 );
        ~wizard();

        KRenameImpl* getKRename() { return krename; }

    private slots:
        void slotAddPage( QWidget* page, const QString & title );
        void slotShowPage( int page );
        void slotEnableFinish( bool b );
        
    protected:
        void accept();
                
        KMenuBar* menuBar;
        KRenameImpl* krename;
};

#endif // WIZARD_H

==> krename_3.0.14.orig.tar.gz: krename-3.0.14/krename/wizard.h <==
/***************************************************************************
                          wizard.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef WIZARD_H
#define WIZARD_H

// KDE includes
#include <kwizard.h>
class QCloseEvent;
class KRenameImpl;
class KMenuBar;
class QCloseEvent;
class QHBoxLayout;
class QRect;
class QString;
class QVBoxLayout;
class QWidget;
class wizard : public KWizard
{ 
    Q_OBJECT

    public:
        wizard( KRenameImpl* impl, QRect r, QWidget* parent = 0, const char* name = 0 );
        ~wizard();

        inline KRenameImpl* getKRename() { return krename; }

    private slots:
        void slotAddPage( QWidget* page, const QString & title );
        void slotShowPage( int page );
        void slotEnableFinish( bool b );
        
    protected:
        void accept();
                
        KMenuBar* menuBar;
        KRenameImpl* krename;
};

#endif // WIZARD_H
